@@ -8,8 +8,8 @@ test_that("output", {
   expect_type(plot_curve(obj4)$bootstrap_data , type = "list")
   expect_type(plot_curve(obj4)$summary_stats , type = "list")
   expect_type(plot_curve(obj4)$models , type = "character")
-  expect_type(plot_curve(obj4)$plot_performance , type = "list")
-  expect_type(plot_curve(obj4)$plot_time , type = "list")
+  # expect_type(plot_curve(obj4)$plot_performance , type = "list")
+  # expect_type(plot_curve(obj4)$plot_time , type = "list")
 })
 
 
